Chain

Struct Chain 

pub struct Chain<N = Waker> { /* private fields */ }
A shared list of intrusively linked objects that can be notified.

Implementations

Source

impl<N> Chain<N>

pub fn new() -> Self

Creates a new, empty chain.

pub fn clear(&mut self)

Removes all the queued-up objects without notifying them.

pub fn is_empty(&self) -> bool

Returns true if this chain is empty.

pub fn notify_one(&self) -> NotifyOne<'_, N>
where N: Subscriber,

Constructs a Notifier for the first linked object.

At most one object is notified once the go-method is called and the chain isn’t empty, but the caller may execute additional methods that change which object is notified and what happens in that case.

The notified object (if any) is automatically removed from the chain.

pub fn notify_all(&self) -> NotifyAll<'_, N>
where N: Subscriber,

Constructs a Notifier for all the linked objects.

Potentially all the objects in the chain are notified when the go method is called, but the caller may execute additional methods that change which objects are notified and what happens in that case.

All notified objects are automatically removed from the chain.

Source

impl Chain<Waker>

pub async fn fifo(&self)

Enters the current process into a FIFO-queue, to be activated later.

The reactivation follows queue-ordering, i.e. first-in first-out.

pub async fn lifo(&self)

Enters the current process into a LIFO-queue, to be activated later.

The reactivation follows stack-ordering, i.e. last-in first-out.