Link

Struct Link 

pub struct Link<N: ?Sized> {
    pub note: N,
    /* private fields */
}
A wrapper type to augment objects that may be notified into intrusive links that can be stored in intrusive collections.

Fields

note: N

The object to be notified.

Implementations

Source

impl<N> Link<N>

pub const fn new(waker: N) -> Self

Initializes a new link with the notifiable object.

pub fn is_linked(&self) -> bool

Returns whether this link is in use or not.

pub fn into_inner(self) -> N

Strips the outer link and returns the inner N.