pub struct NotifyAll<'c, N, P = (), F = (), const REV: bool = false> { /* private fields */ }Expand description
Notification builder that locates, notifies and removes all fitting objects in a Chain.
Implementations
Sourceimpl<'c, N: Subscriber, P, F, const REV: bool> NotifyAll<'c, N, P, F, REV>
impl<'c, N: Subscriber, P, F, const REV: bool> NotifyAll<'c, N, P, F, REV>
Sourcepub fn filter<X: Fn(&N) -> bool>(self, filter: X) -> NotifyAll<'c, N, X, F>
pub fn filter<X: Fn(&N) -> bool>(self, filter: X) -> NotifyAll<'c, N, X, F>
Configures the notification configuration with a boolean predicate that allows skipping the objects that aren’t ready to be notified.
Sourceimpl<'c, N: Subscriber, P, F> NotifyAll<'c, N, P, F, true>
impl<'c, N: Subscriber, P, F> NotifyAll<'c, N, P, F, true>