NotifyOne

Struct NotifyOne 

pub struct NotifyOne<'c, N, P = (), F = (), const FIRST: bool = true> { /* private fields */ }
Notification builder that seeks, notifies and removes the first fitting object in a Chain.

Implementations

Source

impl<'c, N: Subscriber, P, F, const FIRST: bool> NotifyOne<'c, N, P, F, FIRST>

pub fn filter<X: Fn(&N) -> bool>(self, filter: X) -> NotifyOne<'c, N, X, F>

Configures the notification configuration with a boolean predicate that allows skipping the first sequence of objects that aren’t ready to be notified.

pub fn then<X: FnOnce(&N) -> R, R>(self, action: X) -> NotifyOne<'c, N, P, X>

Configures what happens after a suitable object has been found for notification but before it is actually notified.

pub fn first(self) -> NotifyOne<'c, N, P, F, true>

Selects the first item in the chain to be notified.

pub fn last(self) -> NotifyOne<'c, N, P, F, false>

Selects the last item in the chain to be notified.

pub fn go(self) -> <Self as Trigger>::Output
where Self: Trigger,

Triggers the notification.