ArrayBuf

Struct ArrayBuf 

pub struct ArrayBuf<const N: usize, T> { /* private fields */ }
A fixed-size array buffer that can be allocated on the stack and used as a backing store for channels.

Implementations

Source

impl<const N: usize, T> ArrayBuf<N, T>

pub const fn new() -> Self

Creates a new, empty array buffer with a user-defined - but fixed - capacity.