Receiver

Struct Receiver 

pub struct Receiver<T>(/* private fields */);
Available on crate feature alloc only.
The receiving half of the channel. This half can be cloned and is bound to the hosting channel through the reference counted Rc.

Implementations

Source

impl<T> Receiver<T>

pub fn try_recv(&self) -> Result<T, TryRecvError>

Attempts to receive a value of the channel without waiting.

This can fail for two reasons:

  1. The channel is closed, i.e. close has been called.
  2. The message buffer is empty.
pub fn recv(&self) -> RecvFuture<'_, dyn RingBuf<Item = T>>

Returns a future that gets fulfilled when a value is written to the channel. If the channels get closed, the future will resolve to an Err variant.

pub fn count(&self) -> isize

Returns the number of elements currently inside the channel of this receiver.

pub fn close(&self)

Closes the channel from the receiving side. Already sent values may still be received.