pub struct SendFuture<'r, T> { /* private fields */ }Available on crate feature
alloc only.Expand description
Future for the send operation of the shared channel.
We cannot re-use the SendFuture of the channel because our sender only contains a weak reference to the channel.