DefaultPub

Struct DefaultPub 

#[repr(transparent)]
pub struct DefaultPub<T: ?Sized>(pub T);
A wrapper for type-instances that don’t implement Publisher natively.

This structure provides an implementation of the Publisher-trait that doesn’t subscribe to anything and is therefore not alerted when the inner value changes.

Tuple Fields

0: T

Implementations

Source

impl<T> DefaultPub<DefaultExpr<T>>

pub const fn expr_or_publisher(&self) -> DefaultPub<T>

Inherent method that is selected if the type-instance didn’t implement neither Publisher nor Expr.

The returned type doesn’t implement Expr and cannot be used to access the inner instance, leading to compile-time type errors.