Control

Struct Control 

pub struct Control<T: ?Sized> { /* private fields */ }
Marks a variable as a state variable which can be used in conjunction with the until!-macro.

Whenever a control variable changes its value, the runtime system checks whether any other parts of the model are currently waiting for the variable to attain a certain value.

Implementations

Source

impl<T> Control<T>

pub fn new(value: T) -> Self

Creates a new control variable and initializes its value.

pub fn set(&self, val: T)

Assigns a new value to the control variable.

This can lead to potential activations of waiting processes.

pub fn get(&self) -> T
where T: Copy,

Returns a copy of the stored inner value.

pub fn swap(&self, other: &Self)

Swaps the values of two control variables. The difference to core::mem::swap is that this function doesn’t require an exclusive reference.

pub fn replace(&self, val: T) -> T

Replaces the current value of the control variable with a new one and returns it.

This can lead to potential activations of waiting processes.

pub fn update<F>(&self, f: F)
where F: FnOnce(T) -> T, T: Copy,

Updates the contained value using a function and returns the new value.

pub fn take(&self) -> T
where T: Default,

Takes the value of the control variable, leaving Default::default() in its place.

pub fn get_mut(&mut self) -> &mut T

Returns a mutable reference to the underlying data.

This call borrows the control variable mutably (at compile-time) which guarantees that we possess the only reference.

pub fn unchecked_set(&self, val: T)

Assigns a new value to the control variable without notifying pending control conditions.

Use this method if you want to change the inner value without scheduling continuations that depend on it. Once finished, you may call notify directly.