ControlExpr

Struct ControlExpr 

pub struct ControlExpr<C, F> { /* private fields */ }
Container for complex control expressions that combines a set of Control variables with a closure that depends on the values of the control set.

Implementations

Source

impl<C, F> ControlExpr<C, F>
where C: Publisher, F: Fn(&C) -> bool,

pub const fn new(ctrl: C, code: F) -> Self

Creates a new control expression given a set of Control variables and a closure that depends on them.