Until

Struct Until 

pub struct Until<C: Publisher, F> { /* private fields */ }
Notify dispatcher that includes the boolean condition being awaited.

The basic idea is to reduce the number of spurious reactivations of waiting continuations by checking if the condition being awaited evaluated to true for the specific state-change triggering the re-evaluation and not re-awakening the continuation if it doesn’t.

Even if it does, the re-awakened continuation still needs to check the condition since its truth value may have changed between the scheduling and the activation, but this technique still has the potential to cut down on a lot of superfluous scheduling operations.

Implementations

Source

impl<C: Publisher, F> Until<C, F>

pub const fn new(cond: ControlExpr<C, F>) -> Self

Creates a new future that blocks on being awaited until the passed condition is fulfilled.