pub enum TryRecvError {
Empty,
Disconnected,
}Expand description
Signals that a non-blocking attempt at receiving a value through a channel has failed. There are two possible reasons for this: (1) the message buffer of the channel is empty, or (2) the channel is closed.
Variants
Empty
attempt to receive a value has failed because the channel is empty
Disconnected
attempt to receive a value has failed because the channel is disconnected