AllOf

Struct AllOf 

pub struct AllOf<'s, C: ?Sized + Config, J: Joinable<C>> { /* private fields */ }
A combinator for awaiting the completion of multiple futures.

This utility allows you to combine multiple IntoFuture futures into a single future that resolves only after all input futures have completed.

Safety Warning

  • The ordering of fields in AllOf must not be changed. Specifically, the list of Joinable futures must precede the JoinState. Incorrect ordering can lead to undefined behavior due to dangling pointers.

Implementations

Source

impl<'s, C: ?Sized + Config, J: Joinable<C>> AllOf<'s, C, J>

pub fn and<F: IntoFuture>( self, fut: F, ) -> AllOf<'s, C, impl Joinable<C, Output = (J::Output, F::Output)> + use<F, C, J>>

Adds another future to await to the list.