pub struct AnyOf<'s, C: ?Sized + Config, P: Pickable<C>> { /* private fields */ }Expand description
A combinator for awaiting the first future to complete.
This utility resolves when the first future in its collection completes, returning that future’s result.
Behavior
- If multiple futures terminate simultaneously, the one appearing first in the code will take precedence.
- Supports chaining with the
ormethod to combine futures.
Implementations