Joinable

Trait Joinable 

pub trait Joinable<C: ?Sized + Config>: ActiveList<C> {
    type Output;

    // Required methods
    unsafe fn bind(self: Pin<&mut Self>, state: Pin<&JoinState<C>>);
    fn collect(self: Pin<&mut Self>) -> Self::Output;
}
Represents a heterogeneous list of Job to be awaited.

Required Associated Types

type Output

The result tuple type once all jobs complete.

Required Methods

unsafe fn bind(self: Pin<&mut Self>, state: Pin<&JoinState<C>>)

Completes initializing the NotifyQuorum finisher with the shared JoinState.

Safety

The caller has to guarantee that the shared JoinState outlives all Jobs contained in this list.

fn collect(self: Pin<&mut Self>) -> Self::Output

Collects the result list containing the outputs of the futures.

This method panics if not all jobs have terminated.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors