pub struct Chain<N = Waker> { /* private fields */ }Implementations
Sourceimpl<N> Chain<N>
impl<N> Chain<N>
Sourcepub fn notify_one(&self) -> NotifyOne<'_, N>where
N: Subscriber,
pub fn notify_one(&self) -> NotifyOne<'_, N>where
N: Subscriber,
Constructs a Notifier for the first linked object.
At most one object is notified once the go-method is called and the
chain isn’t empty, but the caller may execute additional methods that
change which object is notified and what happens in that case.
The notified object (if any) is automatically removed from the chain.
Sourcepub fn notify_all(&self) -> NotifyAll<'_, N>where
N: Subscriber,
pub fn notify_all(&self) -> NotifyAll<'_, N>where
N: Subscriber,
Constructs a Notifier for all the linked objects.
Potentially all the objects in the chain are notified when the go
method is called, but the caller may execute additional methods that
change which objects are notified and what happens in that case.
All notified objects are automatically removed from the chain.