pub struct Link<N: ?Sized> {
pub note: N,
/* private fields */
}Expand description
A wrapper type to augment objects that may be notified into intrusive links that can be stored in intrusive collections.
Fields
note: NThe object to be notified.
Implementations