NotifyAll

Struct NotifyAll 

pub struct NotifyAll<'c, N, P = (), F = (), const REV: bool = false> { /* private fields */ }
Notification builder that locates, notifies and removes all fitting objects in a Chain.

Implementations

Source

impl<'c, N: Subscriber, P, F, const REV: bool> NotifyAll<'c, N, P, F, REV>

pub fn filter<X: Fn(&N) -> bool>(self, filter: X) -> NotifyAll<'c, N, X, F>

Configures the notification configuration with a boolean predicate that allows skipping the objects that aren’t ready to be notified.

pub fn then<X: FnMut(&N)>(self, action: X) -> NotifyAll<'c, N, P, X>

Configures what happens for every suitable object that has been found for notification right before it is actually notified.

pub fn go(self) -> <Self as Trigger>::Output
where Self: Trigger,

Triggers the notification.

Source

impl<'c, N: Subscriber, P, F> NotifyAll<'c, N, P, F, true>

pub fn rev(self) -> NotifyAll<'c, N, P, F, false>

Reverses the order when triggering.

Source

impl<'c, N: Subscriber, P, F> NotifyAll<'c, N, P, F, false>

pub fn rev(self) -> NotifyAll<'c, N, P, F, true>

Reverses the order when triggering.