pub struct ArrayBuf<const N: usize, T> { /* private fields */ }Expand description
A fixed-size array buffer that can be allocated on the stack and used as a backing store for channels.
Implementations