pub struct Receiver<T>(/* private fields */);Available on crate feature
alloc only.Expand description
The receiving half of the channel. This half can be cloned and is
bound to the hosting channel through the reference counted Rc.
Implementations
Sourceimpl<T> Receiver<T>
impl<T> Receiver<T>
Sourcepub fn try_recv(&self) -> Result<T, TryRecvError>
pub fn try_recv(&self) -> Result<T, TryRecvError>
Attempts to receive a value of the channel without waiting.
This can fail for two reasons:
- The channel is closed, i.e.
closehas been called. - The message buffer is empty.
Sourcepub fn recv(&self) -> RecvFuture<'_, dyn RingBuf<Item = T>> ⓘ
pub fn recv(&self) -> RecvFuture<'_, dyn RingBuf<Item = T>> ⓘ
Returns a future that gets fulfilled when a value is written to the
channel. If the channels get closed, the future will resolve to an
Err variant.