pub struct ControlExpr<C, F> { /* private fields */ }Expand description
Container for complex control expressions that combines a set of Control variables with a closure that depends on the values of the control set.
Implementations