A module for sync-specific error types.
Structs
- Facility
Occupied - Signals that a facility is already seized and cannot be seized at this time.
- Recv
Error - attempted to receive a value from a disconnected channel
- Send
Error - attempt to send a value through a disconnected channel
Enums
- Error
- Enumeration of errors for the functions and structures contained in this module of the simulation library.
- TryRecv
Error - Signals that a non-blocking attempt at receiving a value through a channel has failed. There are two possible reasons for this: (1) the message buffer of the channel is empty, or (2) the channel is closed.
- TrySend
Error - Signals that a non-blocking attempt at sending a value through a channel has failed. There are two possible reasons for this: (1) the message buffer of the channel is full, or (2) the channel is closed.