pub struct AllOf<'s, C: ?Sized + Config, J: Joinable<C>> { /* private fields */ }Expand description
A combinator for awaiting the completion of multiple futures.
This utility allows you to combine multiple IntoFuture futures into a
single future that resolves only after all input futures have completed.
Safety Warning
Implementations